@@ -5,12 +5,11 @@
 """
 App info, license, version
 Python 3.8+
-Author: niftycode
 Date created: June 14th, 2020
-Date modified: April 30th, 2021
+Date modified: August 6th, 2021
 """
 
-VERSION = '0.1.4'
+VERSION = '0.2.0'
 
 
 def app_info():
